from setuptools import setup

setup(name='sshman_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['sshman_probability'],
      zip_safe=False)
